@@ -2,7 +2,7 @@
 #
 #   staticlibs.sh - Remove static library files from the package
 #
-#   Copyright (c) 2013-2016 Pacman Development Team <pacman-dev@archlinux.org>
+#   Copyright (c) 2013-2020 Pacman Development Team <pacman-dev@archlinux.org>
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -34,7 +34,7 @@ tidy_staticlibs() {
 	if check_option "staticlibs" "n"; then
 		msg2 "$(gettext "Removing static library files...")"
 		local l
-		while read -rd '' l; do
+		while IFS= read -rd '' l; do
 			if [[ -f "${l%.a}.so" || -h "${l%.a}.so" ]]; then
 				rm "$l"
 			fi
